import { Dispatcher } from 'flux';
import StoreFactory from './StoreFactory';
import Event from '../event/Event';
import EventHandler from '../event/EventHandler';
declare global {
    interface Window {
        __REDUX_DEVTOOLS_EXTENSION__: DevToolsExtension;
    }
}
export declare type Action = {
    actionType: string;
    type: string;
    data: any;
    payload: any;
};
export declare type StoreGetter<T> = (...args: Array<any>) => T;
export declare type StoreResponse<T> = (state: T, data: any, actionType: string, payload: Action) => any;
export declare type StoreResponses<T> = {
    [key: string]: StoreResponse<T>;
};
export declare type StoreOptions<T> = {
    dispatcher: Dispatcher<any>;
    factory: StoreFactory<T>;
    getter: StoreGetter<T>;
    initialState: T;
    name?: string;
    responses: StoreResponses<T>;
};
declare type DevToolsOptions = {
    name: string;
    instanceId: string;
};
declare type DevToolsMessage = {
    type: string;
    state: any;
    payload: DevToolsMessage;
};
declare type DevToolsExtension = {
    connect: (options: DevToolsOptions) => DevToolsExtension;
    send: (message: string, data: any) => any;
    unsubscribe: () => any;
    subscribe: (callback: (message: DevToolsMessage) => void) => any;
};
export default class Store<T> {
    _dispatcher: Dispatcher<any>;
    _dispatchToken: string;
    _factory: StoreFactory<T>;
    _getter: StoreGetter<T>;
    _event: Event;
    _name: string;
    _responses: StoreResponses<T>;
    _state: any;
    _uid: string;
    _devToolsExtension: DevToolsExtension;
    _unsubscribeDevTools?: () => any;
    constructor({ dispatcher, factory, getter, initialState, name, responses, }: StoreOptions<T>);
    /**
     * Subscribe to changes on this store.
     *
     * @param  callback  will run every time the store responds to a dispatcher
     * @return this
     */
    addOnChange(callback: Function): EventHandler;
    /**
     * Returns the store's referenced value
     *
     * @param  ...  accepts any number of params
     * @return any
     */
    get(...args: any[]): T;
    /**
     * @protected
     * Responds to incoming messages from the Dispatcher
     */
    _handleDispatch(payload: Action): void;
    /**
     * Destroys this instance of the store.
     * Dispatch callback is unregistered. Subscriptions are removed.
     */
    remove(): void;
    toString(): string;
    /**
     * Runs all of the store's subscription callbacks
     *
     * @return this
     */
    triggerChange(): Store<T>;
}
export {};
